@@ -317,23 +317,23 @@ ggit_file_mode_get_type (void)
 	if (the_type == 0)
 	{
 		static const GEnumValue values[] = {
-			{ GGIT_FILEMODE_NEW,
-			  "GGIT_FILEMODE_NEW",
+			{ GGIT_FILE_MODE_NEW,
+			  "GGIT_FILE_MODE_NEW",
 			  "new" },
-			{ GGIT_FILEMODE_TREE,
-			  "GGIT_FILEMODE_TREE",
+			{ GGIT_FILE_MODE_TREE,
+			  "GGIT_FILE_MODE_TREE",
 			  "tree" },
-			{ GGIT_FILEMODE_BLOB,
-			  "GGIT_FILEMODE_BLOB",
+			{ GGIT_FILE_MODE_BLOB,
+			  "GGIT_FILE_MODE_BLOB",
 			  "blob" },
-			{ GGIT_FILEMODE_BLOB_EXECUTABLE,
-			  "GGIT_FILEMODE_BLOB_EXECUTABLE",
+			{ GGIT_FILE_MODE_BLOB_EXECUTABLE,
+			  "GGIT_FILE_MODE_BLOB_EXECUTABLE",
 			  "blob-executable" },
-			{ GGIT_FILEMODE_LINK,
-			  "GGIT_FILEMODE_LINK",
+			{ GGIT_FILE_MODE_LINK,
+			  "GGIT_FILE_MODE_LINK",
 			  "link" },
-			{ GGIT_FILEMODE_COMMIT,
-			  "GGIT_FILEMODE_COMMIT",
+			{ GGIT_FILE_MODE_COMMIT,
+			  "GGIT_FILE_MODE_COMMIT",
 			  "commit" },
 			{ 0, NULL, NULL }
 		};
@@ -344,6 +344,55 @@ ggit_file_mode_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_merge_automerge_mode_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ GGIT_MERGE_AUTOMERGE_MODE_NORMAL,
+			  "GGIT_MERGE_AUTOMERGE_MODE_NORMAL",
+			  "normal" },
+			{ GGIT_MERGE_AUTOMERGE_MODE_NONE,
+			  "GGIT_MERGE_AUTOMERGE_MODE_NONE",
+			  "none" },
+			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS,
+			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS",
+			  "favor-ours" },
+			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS,
+			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS",
+			  "favor-theirs" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("GgitMergeAutomergeMode"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_merge_tree_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_MERGE_TREE_FIND_RENAMES,
+			  "GGIT_MERGE_TREE_FIND_RENAMES",
+			  "renames" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitMergeTreeFlags"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_remote_download_tags_type_get_type (void)
 {
@@ -702,6 +751,12 @@ ggit_status_option_get_type (void)
 			{ GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS,
 			  "GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS",
 			  "recurse-ignored-dirs" },
+			{ GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX,
+			  "GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX",
+			  "renames-head-to-index" },
+			{ GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR,
+			  "GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR",
+			  "renames-index-to-workdir" },
 			{ GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY,
 			  "GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY",
 			  "sort-case-sensitively" },
