@@ -40,6 +40,12 @@ GType ggit_error_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_FILE_MODE	(ggit_file_mode_get_type())
 GType ggit_file_mode_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_MERGE_AUTOMERGE_MODE	(ggit_merge_automerge_mode_get_type())
+GType ggit_merge_automerge_mode_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_MERGE_TREE_FLAGS	(ggit_merge_tree_flags_get_type())
+GType ggit_merge_tree_flags_get_type	(void) G_GNUC_CONST;
+
 #define GGIT_TYPE_REMOTE_DOWNLOAD_TAGS_TYPE	(ggit_remote_download_tags_type_get_type())
 GType ggit_remote_download_tags_type_get_type	(void) G_GNUC_CONST;
 
