@@ -19,20 +19,7 @@
  */
 
 #include <gio/gio.h>
-#include <git2/errors.h>
-#include <git2/repository.h>
-#include <git2/refs.h>
-#include <git2/diff.h>
-#include <git2/status.h>
-#include <git2/tag.h>
-#include <git2/branch.h>
-#include <git2/remote.h>
-#include <git2/reset.h>
-#include <git2/submodule.h>
-#include <git2/revparse.h>
-#include <git2/stash.h>
-#include <git2/graph.h>
-#include <git2/blob.h>
+#include <git2.h>
 
 #include "ggit-error.h"
 #include "ggit-oid.h"
@@ -44,6 +31,7 @@
 #include "ggit-signature.h"
 #include "ggit-clone-options.h"
 #include "ggit-status-options.h"
+#include "ggit-tree-builder.h"
 
 #define GGIT_REPOSITORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GGIT_TYPE_REPOSITORY, GgitRepositoryPrivate))
 
@@ -161,6 +149,7 @@ set_workdir (GgitRepository *repository,
 
 			git_repository_set_workdir (_ggit_native_get (repository),
 			                            path, update_gitlink);
+
 			g_free (path);
 		}
 	}
@@ -374,6 +363,11 @@ ggit_repository_initable_init (GInitable    *initable,
 	                  repo,
 	                  (GDestroyNotify)git_repository_free);
 
+	if (!priv->workdir && !priv->is_bare)
+	{
+		priv->workdir = ggit_repository_get_workdir (GGIT_REPOSITORY (initable));
+	}
+
 	return success;
 }
 
@@ -941,8 +935,8 @@ ggit_repository_get_workdir (GgitRepository *repository)
 /**
  * ggit_repository_set_workdir:
  * @repository: a #GgitRepository.
- * @workdir: the working directory
- * @update_gitlink: create/update gitlink in workdir
+ * @workdir: the working directory.
+ * @update_gitlink: create/update gitlink in workdir.
  *
  * Sets the working directory of the repository. If @update_gitlink is set to
  * %TRUE "core.worktree" will be set in the config if workdir is not the parent
@@ -998,7 +992,7 @@ ggit_repository_file_status (GgitRepository  *repository,
 	g_return_val_if_fail (G_IS_FILE (location), GGIT_STATUS_IGNORED);
 	g_return_val_if_fail (error == NULL || *error == NULL, GGIT_STATUS_IGNORED);
 
-	path = g_file_get_path (location);
+	path = g_file_get_relative_path (repository->priv->workdir, location);
 
 	g_return_val_if_fail (path != NULL, GGIT_STATUS_IGNORED);
 
@@ -1105,8 +1099,8 @@ ggit_repository_references_foreach_name (GgitRepository             *repository,
 
 /**
  * ggit_repository_get_config:
- * @repository: a #GgitRepository
- * @error: a #GError
+ * @repository: a #GgitRepository.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Get the config for a specific repository.
  *
@@ -1138,7 +1132,7 @@ ggit_repository_get_config (GgitRepository  *repository,
 /**
  * ggit_repository_get_index:
  * @repository: a #GgitRepository.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Get the index for a specific repository.
  *
@@ -1175,7 +1169,7 @@ ggit_repository_get_index (GgitRepository  *repository,
  * @tagger: a #GgitSignature.
  * @message: the tag message.
  * @flags: a #GgitCreateFlags.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Create a new tag object.
  *
@@ -1227,7 +1221,7 @@ ggit_repository_create_tag (GgitRepository   *repository,
  * @repository: a #GgitRepository.
  * @tag: the tag buffer.
  * @flags: a #GgitCreateFlags.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Create a new tag from a buffer describing the tag object. The buffer must
  * be correctly formatted.
@@ -1272,7 +1266,7 @@ ggit_repository_create_tag_from_buffer (GgitRepository   *repository,
  * @tag_name: the name of the tag.
  * @target: a #GgitObject.
  * @flags: a #GgitCreateFlags.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Creates a new lightweight tag.
  *
@@ -1316,7 +1310,7 @@ ggit_repository_create_tag_lightweight (GgitRepository   *repository,
 /**
  * ggit_repository_list_tags:
  * @repository: a #GgitRepository.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Fill a list with all the tags in the @repository.
  *
@@ -1355,7 +1349,7 @@ ggit_repository_list_tags (GgitRepository  *repository,
  * @branch_name: the name of the branch.
  * @target: a #GgitObject.
  * @flags: a #GgitCreateFlags.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Creates a new branch pointing at a target commit.
  *
@@ -1405,7 +1399,7 @@ typedef gint (* _GitBranchesCallback) (const gchar  *branch_name,
  * @branch_type: a GgitBranchType.
  * @callback: (scope call): a #GgitBranchesCallback.
  * @user_data: callback user data.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Foreach branch of type @branch_type the callback @callback is called.
  **/
@@ -1475,7 +1469,7 @@ ggit_repository_lookup_branch (GgitRepository *repository,
  * ggit_repository_get_remote:
  * @repository: a #GgitRepository.
  * @name: the remote's name.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Gets the remote called @name.
  *
@@ -1511,7 +1505,7 @@ ggit_repository_get_remote (GgitRepository  *repository,
  * @repository: a #GgitRepository.
  * @name: the name of the new remote.
  * @url: the url of the remote.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Adds a remote with the default fetch refspec to the repository's configuration.
  *
@@ -1547,7 +1541,7 @@ ggit_repository_create_remote (GgitRepository  *repository,
 /**
  * ggit_repository_list_remotes:
  * @repository: a #GgitRepository.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Fill a list with all the remotes in @repository.
  *
@@ -1584,7 +1578,7 @@ ggit_repository_list_remotes (GgitRepository  *repository,
  * ggit_repository_lookup_submodule:
  * @repository: a #GgitRepository.
  * @name: the name of the submodule.
- * @error: a #GError.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Lookups a submodule information by name or path. If the submodule
  * does not exist, %NULL is returned and a GGIT_ERROR_NOTFOUND error set.
@@ -1767,7 +1761,7 @@ ggit_repository_save_stash (GgitRepository  *repository,
 /**
  * ggit_repository_drop_stash:
  * @repository: a #GgitRepository.
- * @index: the position within the stash list. 0 points to the
+ * @index: the position within the stash list. 0 points to the.
  * most recent stashed state.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -1902,6 +1896,25 @@ ggit_repository_get_ahead_behind (GgitRepository  *repository,
 	}
 }
 
+/**
+ * ggit_repository_create_blob:
+ * @repository: a #GgitRepository.
+ *
+ * Create a new blob and return a #GOutputStream to write contents to the blob.
+ * This is an efficient way to create new blobs without copying data. The
+ * blob id can be obtained from the blob output stream using
+ * #ggit_blob_output_stream_get_id, after you close the stream.
+ *
+ * Returns: (transfer full): a #GgitBlobOutputStream.
+ *
+ **/
+GgitBlobOutputStream *
+ggit_repository_create_blob (GgitRepository *repository)
+{
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	return _ggit_blob_output_stream_new (repository);
+}
+
 /**
  * ggit_repository_create_blob_from_buffer:
  * @repository: a #GgitRepository.
@@ -1911,7 +1924,7 @@ ggit_repository_get_ahead_behind (GgitRepository  *repository,
  *
  * Write an in-memory buffer to the object database as a blob.
  *
- * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * Returns: the new #GgitOid of the written blob, or %NULL if writing the blob
  * failed.
  */
 GgitOId *
@@ -1949,7 +1962,7 @@ ggit_repository_create_blob_from_buffer (GgitRepository  *repository,
  *
  * Write a file to the object database as a blob.
  *
- * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * Returns: the new #GgitOid of the written blob, or %NULL if writing the blob
  * failed.
  */
 GgitOId *
@@ -1991,7 +2004,7 @@ ggit_repository_create_blob_from_file (GgitRepository  *repository,
  * Write a path relative to the repository working directory to the object
  * database as a blob.
  *
- * @return the new #GgitOid of the written blob, or %NULL if writing the blob
+ * Returns: the new #GgitOid of the written blob, or %NULL if writing the blob
  * failed.
  */
 GgitOId *
@@ -2019,4 +2032,248 @@ ggit_repository_create_blob_from_path (GgitRepository  *repository,
 	return _ggit_oid_wrap (&oid);
 }
 
+/**
+ * ggit_repository_create_commit:
+ * @repository: a #GgitRepository.
+ * @update_ref: (allow-none): name of the reference to update.
+ * @author: author signature.
+ * @committer: committer signature (and time of commit).
+ * @message_encoding: (allow-none): message encoding.
+ * @message: commit message.
+ * @tree: the tree of objects to commit.
+ * @parents: (array length=parent_count): parent commits.
+ * @parent_count: number of parent commits in @parents.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Create a new commit. If @update_ref is not %NULL, the given reference will
+ * be updated to point to the newly created commit. Use "HEAD" to update the
+ * HEAD of the current branch and make it point to this commit.
+ *
+ * If @message_encoding is set to %NULL, "UTF-8" encoding is assumed for the
+ * provided @message. Note that @message will not be cleaned up automatically.
+ * You can use #ggit_message_prettify to do this yourself if needed.
+ *
+ * Returns: the #GgitOId of the created commit object, or %NULL in case of an error.
+ *
+ */
+GgitOId *
+ggit_repository_create_commit (GgitRepository  *repository,
+                               const gchar     *update_ref,
+                               GgitSignature   *author,
+                               GgitSignature   *committer,
+                               const gchar     *message_encoding,
+                               const gchar     *message,
+                               GgitTree        *tree,
+                               GgitCommit     **parents,
+                               gint             parent_count,
+                               GError         **error)
+{
+	gint ret;
+	git_oid oid;
+	git_commit **parents_native;
+	gint i;
+
+	parents_native = g_new0 (git_commit *, parent_count);
+
+	for (i = 0; i < parent_count; ++i)
+	{
+		parents_native[i] = _ggit_native_get (parents[i]);
+	}
+
+	ret = git_commit_create (&oid,
+	                         _ggit_native_get (repository),
+	                         update_ref,
+	                         _ggit_native_get (author),
+	                         _ggit_native_get (committer),
+	                         message_encoding,
+	                         message,
+	                         _ggit_native_get (tree),
+	                         parent_count,
+	                         (const git_commit **)parents_native);
+
+	g_free (parents_native);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_oid_wrap (&oid);
+}
+
+/**
+ * ggit_repository_create_tree_builder:
+ * @repository: a #GgitRepository.
+ *
+ * Create a new tree builder.
+ *
+ * Returns: (transfer full): a #GgitTreeBuilder.
+ *
+ **/
+GgitTreeBuilder *
+ggit_repository_create_tree_builder (GgitRepository *repository)
+{
+	git_treebuilder *builder;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+
+	git_treebuilder_create (&builder, NULL);
+	return _ggit_tree_builder_wrap (builder, repository, TRUE);
+}
+
+/**
+ * ggit_repository_create_tree_builder_from_tree:
+ * @tree: a #GgitTree.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Create a tree builder for initialized with @tree. To create an empty
+ * tree builder, use #ggit_repository_create_tree_builder instead.
+ *
+ * Returns: (transfer full): a new #GgitTreeBuilder object, or %NULL if there was an error.
+ *
+ **/
+GgitTreeBuilder *
+ggit_repository_create_tree_builder_from_tree (GgitRepository  *repository,
+                                               GgitTree        *tree,
+                                               GError         **error)
+{
+	gint ret;
+	git_treebuilder *builder;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (GGIT_IS_TREE (tree), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	ret = git_treebuilder_create (&builder, _ggit_native_get (tree));
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_tree_builder_wrap (builder, repository, TRUE);
+}
+
+/**
+ * ggit_repository_create_index_entry_for_file:
+ * @repository: a #GgitRepository.
+ * @file: (allow-none): a #GFile.
+ * @id: (allow-none): a #GgitOId.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Create a new index entry. When @file is not %NULL, the path of the returned
+ * entry (#ggit_index_entry_get_path) is set to the path of @file relative to
+ * the working directory of @repository. The file must reside in the working
+ * directory of @repository. The file related
+ * fields of the returned entry are also queried from this file (if the file exists).
+ *
+ * If @id is not %NULL, then the id of the returned entry is set to @id
+ * (see #ggit_index_entry_get_id) which could point to a blob (for a file)
+ * or a tree (for a directory).
+ *
+ * Returns: a #GgitIndexEntry or %NULL when an error occurred.
+ *
+ **/
+GgitIndexEntry *
+ggit_repository_create_index_entry_for_file (GgitRepository  *repository,
+                                             GFile           *file,
+                                             GgitOId         *id,
+                                             GError         **error)
+{
+	gchar *path = NULL;
+	GgitIndexEntry *ret;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (file == NULL || G_IS_FILE (file), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	if (file != NULL)
+	{
+		path = g_file_get_relative_path (repository->priv->workdir,
+		                                 file);
+
+		if (!path)
+		{
+			g_set_error_literal (error,
+			                     G_IO_ERROR,
+			                     G_IO_ERROR_NOT_FOUND,
+			                     "File is not in the working directory");
+
+			return NULL;
+		}
+	}
+
+	ret = _ggit_index_entry_new (path, id);
+	g_free (path);
+
+	if (file)
+	{
+		ggit_index_entry_stat (ret, file, NULL);
+	}
+
+	return ret;
+}
+
+/**
+ * ggit_repository_create_index_entry_for_path:
+ * @repository: a #GgitRepository.
+ * @path: (allow-none): a path.
+ * @id: (allow-none): a #GgitOId.
+ * @error: a #GError for error reporting, or %NULL.
+ *
+ * Create a new index entry. When @path is not %NULL, the path of the returned
+ * entry (#ggit_index_entry_get_path) is set @path. The specified path can be
+ * either absolute or relative. In the case of
+ * an absolute path, the path must reside within the working directory of
+ * @repository. The file related fields of the returned entry are also queried
+ * from this path (if the file exists).
+ *
+ * If @id is not %NULL, then the id of the returned entry is set to @id
+ * (see #ggit_index_entry_get_id) which could point to a blob (for a file)
+ * or a tree (for a directory).
+ *
+ * Returns: a #GgitIndexEntry or %NULL when an error occurred.
+ *
+ **/
+GgitIndexEntry *
+ggit_repository_create_index_entry_for_path (GgitRepository  *repository,
+                                             const gchar     *path,
+                                             GgitOId         *id,
+                                             GError         **error)
+{
+	GFile *f;
+	GgitIndexEntry *ret;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	if (path)
+	{
+		if (!g_path_is_absolute (path))
+		{
+			f = g_file_resolve_relative_path (repository->priv->workdir,
+				                          path);
+		}
+		else
+		{
+			f = g_file_new_for_path (path);
+		}
+	}
+	else
+	{
+		f = NULL;
+	}
+
+	ret = ggit_repository_create_index_entry_for_file (repository,
+	                                                   f,
+	                                                   id,
+	                                                   error);
+
+	g_object_unref (f);
+
+	return ret;
+}
+
 /* ex:set ts=8 noet: */
