@@ -23,7 +23,7 @@
 #define __GGIT_REPOSITORY_H__
 
 #include <glib-object.h>
-#include <git2/repository.h>
+#include <git2.h>
 #include <gio/gio.h>
 #include <libgit2-glib/ggit-config.h>
 #include <libgit2-glib/ggit-index.h>
@@ -32,6 +32,7 @@
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-branch.h>
+#include <libgit2-glib/ggit-blob-output-stream.h>
 
 G_BEGIN_DECLS
 
@@ -104,6 +105,10 @@ GgitRef            *ggit_repository_create_symbolic_reference
                                                        const gchar           *target,
                                                        GError               **error);
 
+GgitBlobOutputStream *
+                    ggit_repository_create_blob       (GgitRepository        *repository);
+
+
 GgitOId            *ggit_repository_create_blob_from_buffer (
                                                        GgitRepository        *repository,
                                                        gconstpointer          buffer,
@@ -120,6 +125,17 @@ GgitOId            *ggit_repository_create_blob_from_path (
                                                        const gchar           *path,
                                                        GError               **error);
 
+GgitOId            *ggit_repository_create_commit     (GgitRepository        *repository,
+                                                       const gchar           *update_ref,
+                                                       GgitSignature         *author,
+                                                       GgitSignature         *committer,
+                                                       const gchar           *message_encoding,
+                                                       const gchar           *message,
+                                                       GgitTree              *tree,
+                                                       GgitCommit           **parents,
+                                                       gint                   parent_count,
+                                                       GError               **error);
+
 GgitOId            *ggit_repository_create_tag        (GgitRepository        *repository,
                                                        const gchar           *tag_name,
                                                        GgitObject            *target,
@@ -141,6 +157,26 @@ GgitOId            *ggit_repository_create_tag_lightweight (
                                                        GgitCreateFlags        flags,
                                                        GError               **error);
 
+GgitTreeBuilder    *ggit_repository_create_tree_builder_from_tree (
+                                                       GgitRepository        *repository,
+                                                       GgitTree              *tree,
+                                                       GError               **error);
+
+GgitTreeBuilder    *ggit_repository_create_tree_builder (
+                                                       GgitRepository        *repository);
+
+GgitIndexEntry     *ggit_repository_create_index_entry_for_file (
+                                                       GgitRepository        *repository,
+                                                       GFile                 *file,
+                                                       GgitOId               *id,
+                                                       GError               **error);
+
+GgitIndexEntry     *ggit_repository_create_index_entry_for_path (
+                                                       GgitRepository        *repository,
+                                                       const gchar           *path,
+                                                       GgitOId               *id,
+                                                       GError               **error);
+
 gchar             **ggit_repository_list_tags         (GgitRepository        *repository,
                                                        GError               **error);
 
