@@ -23,7 +23,7 @@
 #include "ggit-repository.h"
 #include "ggit-error.h"
 
-#include <git2/errors.h>
+#include <git2.h>
 
 
 struct _GgitSubmodule
@@ -114,7 +114,7 @@ ggit_submodule_save (GgitSubmodule  *submodule,
 
 /**
  * ggit_submodule_get_owner:
- * @submodule: a #GgitSubmodule
+ * @submodule: a #GgitSubmodule.
  *
  * Gets the containing repository for a submodule.
  *
