@@ -18,16 +18,7 @@
  * along with libgit2-glib. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <git2/diff.h>
-#include <git2/errors.h>
-#include <git2/revwalk.h>
-#include <git2/status.h>
-#include <git2/submodule.h>
-#include <git2/types.h>
-#include <git2/config.h>
-#include <git2/stash.h>
-#include <git2/reset.h>
-#include <git2/remote.h>
+#include <git2.h>
 
 #include "ggit-types.h"
 
@@ -96,12 +87,19 @@ ASSERT_ENUM (GGIT_ERROR_BUFS,        GIT_EBUFS);
 ASSERT_ENUM (GGIT_ERROR_PASSTHROUGH, GIT_PASSTHROUGH);
 ASSERT_ENUM (GGIT_ERROR_ITEROVER,    GIT_ITEROVER);
 
-ASSERT_ENUM (GGIT_FILEMODE_NEW, GIT_FILEMODE_NEW);
-ASSERT_ENUM (GGIT_FILEMODE_TREE, GIT_FILEMODE_TREE);
-ASSERT_ENUM (GGIT_FILEMODE_BLOB, GIT_FILEMODE_BLOB);
-ASSERT_ENUM (GGIT_FILEMODE_BLOB_EXECUTABLE, GIT_FILEMODE_BLOB_EXECUTABLE);
-ASSERT_ENUM (GGIT_FILEMODE_LINK, GIT_FILEMODE_LINK);
-ASSERT_ENUM (GGIT_FILEMODE_COMMIT, GIT_FILEMODE_COMMIT);
+ASSERT_ENUM (GGIT_FILE_MODE_NEW, GIT_FILEMODE_NEW);
+ASSERT_ENUM (GGIT_FILE_MODE_TREE, GIT_FILEMODE_TREE);
+ASSERT_ENUM (GGIT_FILE_MODE_BLOB, GIT_FILEMODE_BLOB);
+ASSERT_ENUM (GGIT_FILE_MODE_BLOB_EXECUTABLE, GIT_FILEMODE_BLOB_EXECUTABLE);
+ASSERT_ENUM (GGIT_FILE_MODE_LINK, GIT_FILEMODE_LINK);
+ASSERT_ENUM (GGIT_FILE_MODE_COMMIT, GIT_FILEMODE_COMMIT);
+
+ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_NORMAL, GIT_MERGE_AUTOMERGE_NORMAL);
+ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_NONE, GIT_MERGE_AUTOMERGE_NONE);
+ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS, GIT_MERGE_AUTOMERGE_FAVOR_OURS);
+ASSERT_ENUM (GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS, GIT_MERGE_AUTOMERGE_FAVOR_THEIRS);
+
+ASSERT_ENUM (GGIT_MERGE_TREE_FIND_RENAMES, GIT_MERGE_TREE_FIND_RENAMES);
 
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,  GIT_REMOTE_DOWNLOAD_TAGS_AUTO);
 ASSERT_ENUM (GGIT_REMOTE_DOWNLOAD_TAGS_NONE,  GIT_REMOTE_DOWNLOAD_TAGS_NONE);
@@ -175,6 +173,10 @@ ASSERT_ENUM (GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES, GIT_STATUS_OPT_EXCLUDE_SUBMO
 ASSERT_ENUM (GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS, GIT_STATUS_OPT_RECURSE_UNTRACKED_DIRS);
 ASSERT_ENUM (GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH, GIT_STATUS_OPT_DISABLE_PATHSPEC_MATCH);
 ASSERT_ENUM (GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS, GIT_STATUS_OPT_RECURSE_IGNORED_DIRS);
+ASSERT_ENUM (GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX, GIT_STATUS_OPT_RENAMES_HEAD_TO_INDEX);
+ASSERT_ENUM (GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR, GIT_STATUS_OPT_RENAMES_INDEX_TO_WORKDIR);
+ASSERT_ENUM (GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY, GIT_STATUS_OPT_SORT_CASE_INSENSITIVELY);
+ASSERT_ENUM (GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY, GIT_STATUS_OPT_SORT_CASE_SENSITIVELY);
 ASSERT_ENUM (GGIT_STATUS_OPTION_DEFAULT, GIT_STATUS_OPT_DEFAULTS);
 
 ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_AND_WORKDIR, GIT_STATUS_SHOW_INDEX_AND_WORKDIR);
