@@ -32,6 +32,13 @@ G_BEGIN_DECLS
  */
 typedef struct _GgitBlob GgitBlob;
 
+/**
+ * GgitBlobOutputStream:
+ *
+ * Represents a blob stream object.
+ */
+typedef struct _GgitBlobOutputStream GgitBlobOutputStream;
+
 /**
  * GgitBranch:
  *
@@ -89,11 +96,11 @@ typedef struct _GgitCred GgitCred;
 typedef struct _GgitCredPlaintext GgitCredPlaintext;
 
 /**
- * GgitDiff:
+ * GgitDiffList:
  *
- * Represents a diff.
+ * Represents a diff list.
  */
-typedef struct _GgitDiff GgitDiff;
+typedef struct _GgitDiffList GgitDiffList;
 
 /**
  * GgitDiffDelta:
@@ -102,6 +109,13 @@ typedef struct _GgitDiff GgitDiff;
  */
 typedef struct _GgitDiffDelta GgitDiffDelta;
 
+/**
+ * GgitDiffPatch:
+ *
+ * Represents a patch object.
+ */
+typedef struct _GgitDiffPatch GgitDiffPatch;
+
 /**
  * GgitDiffFile:
  *
@@ -158,6 +172,13 @@ typedef struct _GgitIndexEntriesResolveUndo GgitIndexEntriesResolveUndo;
  */
 typedef struct _GgitIndexEntryResolveUndo GgitIndexEntryResolveUndo;
 
+/**
+ * GgitMergeTreeOptions:
+ *
+ * Represents the options used when merging.
+ */
+typedef struct _GgitMergeTreeOptions GgitMergeTreeOptions;
+
 /**
  * GgitNative:
  *
@@ -484,14 +505,37 @@ typedef enum {
 
 /* NOTE: keep in sync with git2/refs.h */
 typedef enum {
-	GGIT_FILEMODE_NEW             = 0000000,
-	GGIT_FILEMODE_TREE            = 0040000,
-	GGIT_FILEMODE_BLOB            = 0100644,
-	GGIT_FILEMODE_BLOB_EXECUTABLE = 0100755,
-	GGIT_FILEMODE_LINK            = 0120000,
-	GGIT_FILEMODE_COMMIT          = 0160000
+	GGIT_FILE_MODE_NEW             = 0000000,
+	GGIT_FILE_MODE_TREE            = 0040000,
+	GGIT_FILE_MODE_BLOB            = 0100644,
+	GGIT_FILE_MODE_BLOB_EXECUTABLE = 0100755,
+	GGIT_FILE_MODE_LINK            = 0120000,
+	GGIT_FILE_MODE_COMMIT          = 0160000
 } GgitFileMode;
 
+/* NOTE: keep in sync with git2/merge.h */
+/**
+ * GgitMergeAutomergeMode:
+ * @GGIT_MERGE_AUTOMERGE_MODE_NORMAL:
+ * @GGIT_MERGE_AUTOMERGE_MODE_NONE:
+ * @GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS:
+ * @GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS:
+ */
+typedef enum {
+	GGIT_MERGE_AUTOMERGE_MODE_NORMAL       = 0,
+	GGIT_MERGE_AUTOMERGE_MODE_NONE         = 1,
+	GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS   = 2,
+	GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS = 3
+} GgitMergeAutomergeMode;
+
+/**
+ * GgitMergeTreeFlags:
+ * @GGIT_MERGE_TREE_FIND_RENAMES: detect renames.
+ */
+typedef enum {
+	GGIT_MERGE_TREE_FIND_RENAMES = (1 << 0)
+} GgitMergeTreeFlags;
+
 /* NOTE: keep in sync with git2/refs.h */
 /**
  * GgitRemoteDownloadTagsType:
@@ -684,6 +728,12 @@ typedef enum {
  * GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS: search untracked directories recursively (default).
  * GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH: do not match path specifications.
  * GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS: search ignored directories recursively.
+ * GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX: indicates that rename detection
+ * should be processed between the head and the index and enables
+ * the GIT_STATUS_INDEX_RENAMED as a possible status flag.
+ * GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR: indicates tha rename
+ * detection should be run between the index and the working directory
+ * and enabled GIT_STATUS_WT_RENAMED as a possible status flag.
  * GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY: sort case sensitive.
  * GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY: sort case insensitive.
  * GGIT_STATUS_OPTION_DEFAULT: default flags.
@@ -699,6 +749,8 @@ typedef enum {
 	GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS   = (1 << 4),
 	GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH   = (1 << 5),
 	GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS     = (1 << 6),
+	GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX    = (1 << 7),
+	GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR = (1 << 8),
 	GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY    = (1 << 9),
 	GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY  = (1 << 10),
 	GGIT_STATUS_OPTION_DEFAULT                  = GGIT_STATUS_OPTION_INCLUDE_IGNORED |
@@ -931,8 +983,8 @@ typedef gint (* GgitSubmoduleCallback) (GgitSubmodule *submodule,
  *
  * Returns: a value less than zero to cancel the transfer.
  */
-typedef gint (* GgitTransferProgressCallback) (const GgitTransferProgress *stats,
-                                               gpointer                    user_data);
+typedef gint (* GgitTransferProgressCallback) (GgitTransferProgress *stats,
+                                               gpointer              user_data);
 
 /**
  * GgitTreeWalkCallback:
